==> openshift-model-6.0.0-sources.jar: io/fabric8/openshift/api/model/TLSConfigFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TLSConfigFluentImpl<A extends TLSConfigFluent<A>> extends BaseFluent<A> implements TLSConfigFluent<A>{
  public TLSConfigFluentImpl() {
  }
  public TLSConfigFluentImpl(TLSConfig instance) {
    this.withCaCertificate(instance.getCaCertificate()); 
    this.withCertificate(instance.getCertificate()); 
    this.withDestinationCACertificate(instance.getDestinationCACertificate()); 
    this.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy()); 
    this.withKey(instance.getKey()); 
    this.withTermination(instance.getTermination()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String caCertificate;
  private String certificate;
  private String destinationCACertificate;
  private String insecureEdgeTerminationPolicy;
  private String key;
  private String termination;
  private Map<String,Object> additionalProperties;
  public String getCaCertificate() {
    return this.caCertificate;
  }
  public A withCaCertificate(String caCertificate) {
    this.caCertificate=caCertificate; return (A) this;
  }
  public Boolean hasCaCertificate() {
    return this.caCertificate != null;
  }
  public String getCertificate() {
    return this.certificate;
  }
  public A withCertificate(String certificate) {
    this.certificate=certificate; return (A) this;
  }
  public Boolean hasCertificate() {
    return this.certificate != null;
  }
  public String getDestinationCACertificate() {
    return this.destinationCACertificate;
  }
  public A withDestinationCACertificate(String destinationCACertificate) {
    this.destinationCACertificate=destinationCACertificate; return (A) this;
  }
  public Boolean hasDestinationCACertificate() {
    return this.destinationCACertificate != null;
  }
  public String getInsecureEdgeTerminationPolicy() {
    return this.insecureEdgeTerminationPolicy;
  }
  public A withInsecureEdgeTerminationPolicy(String insecureEdgeTerminationPolicy) {
    this.insecureEdgeTerminationPolicy=insecureEdgeTerminationPolicy; return (A) this;
  }
  public Boolean hasInsecureEdgeTerminationPolicy() {
    return this.insecureEdgeTerminationPolicy != null;
  }
  public String getKey() {
    return this.key;
  }
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  public Boolean hasKey() {
    return this.key != null;
  }
  public String getTermination() {
    return this.termination;
  }
  public A withTermination(String termination) {
    this.termination=termination; return (A) this;
  }
  public Boolean hasTermination() {
    return this.termination != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TLSConfigFluentImpl that = (TLSConfigFluentImpl) o;
    if (caCertificate != null ? !caCertificate.equals(that.caCertificate) :that.caCertificate != null) return false;
    if (certificate != null ? !certificate.equals(that.certificate) :that.certificate != null) return false;
    if (destinationCACertificate != null ? !destinationCACertificate.equals(that.destinationCACertificate) :that.destinationCACertificate != null) return false;
    if (insecureEdgeTerminationPolicy != null ? !insecureEdgeTerminationPolicy.equals(that.insecureEdgeTerminationPolicy) :that.insecureEdgeTerminationPolicy != null) return false;
    if (key != null ? !key.equals(that.key) :that.key != null) return false;
    if (termination != null ? !termination.equals(that.termination) :that.termination != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caCertificate,  certificate,  destinationCACertificate,  insecureEdgeTerminationPolicy,  key,  termination,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caCertificate != null) { sb.append("caCertificate:"); sb.append(caCertificate + ","); }
    if (certificate != null) { sb.append("certificate:"); sb.append(certificate + ","); }
    if (destinationCACertificate != null) { sb.append("destinationCACertificate:"); sb.append(destinationCACertificate + ","); }
    if (insecureEdgeTerminationPolicy != null) { sb.append("insecureEdgeTerminationPolicy:"); sb.append(insecureEdgeTerminationPolicy + ","); }
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (termination != null) { sb.append("termination:"); sb.append(termination + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/TLSConfigFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TLSConfigFluentImpl<A extends TLSConfigFluent<A>> extends BaseFluent<A> implements TLSConfigFluent<A>{
  public TLSConfigFluentImpl() {
  }
  public TLSConfigFluentImpl(TLSConfig instance) {
    if (instance != null) {
      this.withCaCertificate(instance.getCaCertificate());
      this.withCertificate(instance.getCertificate());
      this.withDestinationCACertificate(instance.getDestinationCACertificate());
      this.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy());
      this.withKey(instance.getKey());
      this.withTermination(instance.getTermination());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String caCertificate;
  private String certificate;
  private String destinationCACertificate;
  private String insecureEdgeTerminationPolicy;
  private String key;
  private String termination;
  private Map<String,Object> additionalProperties;
  public String getCaCertificate() {
    return this.caCertificate;
  }
  public A withCaCertificate(String caCertificate) {
    this.caCertificate=caCertificate; return (A) this;
  }
  public Boolean hasCaCertificate() {
    return this.caCertificate != null;
  }
  public String getCertificate() {
    return this.certificate;
  }
  public A withCertificate(String certificate) {
    this.certificate=certificate; return (A) this;
  }
  public Boolean hasCertificate() {
    return this.certificate != null;
  }
  public String getDestinationCACertificate() {
    return this.destinationCACertificate;
  }
  public A withDestinationCACertificate(String destinationCACertificate) {
    this.destinationCACertificate=destinationCACertificate; return (A) this;
  }
  public Boolean hasDestinationCACertificate() {
    return this.destinationCACertificate != null;
  }
  public String getInsecureEdgeTerminationPolicy() {
    return this.insecureEdgeTerminationPolicy;
  }
  public A withInsecureEdgeTerminationPolicy(String insecureEdgeTerminationPolicy) {
    this.insecureEdgeTerminationPolicy=insecureEdgeTerminationPolicy; return (A) this;
  }
  public Boolean hasInsecureEdgeTerminationPolicy() {
    return this.insecureEdgeTerminationPolicy != null;
  }
  public String getKey() {
    return this.key;
  }
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  public Boolean hasKey() {
    return this.key != null;
  }
  public String getTermination() {
    return this.termination;
  }
  public A withTermination(String termination) {
    this.termination=termination; return (A) this;
  }
  public Boolean hasTermination() {
    return this.termination != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TLSConfigFluentImpl that = (TLSConfigFluentImpl) o;
    if (!java.util.Objects.equals(caCertificate, that.caCertificate)) return false;

    if (!java.util.Objects.equals(certificate, that.certificate)) return false;

    if (!java.util.Objects.equals(destinationCACertificate, that.destinationCACertificate)) return false;

    if (!java.util.Objects.equals(insecureEdgeTerminationPolicy, that.insecureEdgeTerminationPolicy)) return false;

    if (!java.util.Objects.equals(key, that.key)) return false;

    if (!java.util.Objects.equals(termination, that.termination)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caCertificate,  certificate,  destinationCACertificate,  insecureEdgeTerminationPolicy,  key,  termination,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caCertificate != null) { sb.append("caCertificate:"); sb.append(caCertificate + ","); }
    if (certificate != null) { sb.append("certificate:"); sb.append(certificate + ","); }
    if (destinationCACertificate != null) { sb.append("destinationCACertificate:"); sb.append(destinationCACertificate + ","); }
    if (insecureEdgeTerminationPolicy != null) { sb.append("insecureEdgeTerminationPolicy:"); sb.append(insecureEdgeTerminationPolicy + ","); }
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (termination != null) { sb.append("termination:"); sb.append(termination + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
